"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const yoga_layout_1 = require("yoga-layout");
class GtkContainer {
    constructor(window) {
        this.layout = yoga_layout_1.Node.createDefault();
        this.children = new Array();
        this.window = window;
    }
    appendChild(child) {
        this.layout.insertChild(child.layout, this.layout.getChildCount());
        this.children.push(child);
        this.window.add(child.node);
        this.window.showAll();
    }
    removeChild(child) {
        // TODO this is not where we want to clean
        // up the layout tree. We need to design how
        // components create/update/mount/unmount/destroy.
        // properly. This will be part of the unmount
        // phase. The problem here is that components
        // that unmount deeper in the tree will not
        // free their layout nodes until the entire
        // tree is unmounted (the container is unmounted).
        child.layout.freeRecursive();
    }
    layoutChildren() {
        this.layout.calculateLayout();
        this.children.forEach((child) => child.layoutChildren());
    }
}
exports.default = GtkContainer;
// I'm not sure where to put this yet.
// it's a quick global function to print the entire
// tree of layout nodes as a json object. It's useful
// to call from the debugger to see what Yoga thinks the
// layout should look like vs. what the layout actually is.
function debugLayoutAux(component) {
    const layoutNode = component.layout;
    const layout = {};
    layout.component = component.constructor.name;
    layout.width = layoutNode.getComputedWidth();
    layout.height = layoutNode.getComputedHeight();
    layout.left = layoutNode.getComputedLeft();
    layout.top = layoutNode.getComputedTop();
    if (layoutNode.getChildCount() === 0) {
        return layout;
    }
    layout.children = [];
    const childCount = component.children.length;
    for (let i = 0; i < childCount; i++) {
        layout.children.push(debugLayoutAux(component.children[i]));
    }
    return layout;
}
global.debugLayout = (component) => {
    const result = debugLayoutAux(component);
    console.log(JSON.stringify(result, undefined, 2)); // tslint:disable-line no-magic-numbers no-console
    return result;
};
