"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const yoga_layout_1 = require("yoga-layout");
const flex_1 = require("../flexbox/flex");
const styleShorthands_1 = require("../style/styleShorthands");
class GtkComponent {
    constructor(props) {
        this.children = new Array();
        this.layout = yoga_layout_1.Node.createDefault();
        this.acceptProps(props);
    }
    acceptProps(props) {
        this.props = Object.assign({}, this.constructor.defaultProps, props);
        this.props.style = Object.assign({}, this.constructor.defaultStyle, this.props.style);
    }
    commitMount() {
        this.update();
    }
    commitUpdate(newProps) {
        this.acceptProps(newProps);
        this.update();
    }
    update() {
        this.setProps();
        this.node.showAll(); // if chil nodes are added we want to show them automatically!
    }
    appendChild(child) {
        this.children.push(child);
        this.layout.insertChild(child.layout, this.layout.getChildCount());
    }
    removeChild(child) {
        // O(n) removal of children needs to be optimised at some point! (react keys?)
        const index = this.children.indexOf(child);
        this.children.splice(index, 1);
        this.layout.removeChild(child.layout);
    }
    layoutChildren() {
        for (const child of this.children) {
            child.layoutChildren();
        }
    }
    setProps() {
        for (const [key, value] of Object.entries(this.props)) {
            if (key === 'style') {
                this.applyStyles(value);
            }
            this.setProp(key, value);
        }
    }
    setProp(prop, value) {
        // no-op
        return undefined;
    }
    applyStyles(style) {
        const copy = Object.assign({}, style);
        const expandedStyles = styleShorthands_1.expandStyleShorthands(copy);
        // apply flexbox styles
        flex_1.default(expandedStyles, this.layout);
        // set widget size request
        let { width, height } = expandedStyles;
        if (width === undefined) {
            width = -1; // -1 tell's GTK to unset the size request
        }
        if (height === undefined) {
            height = -1; // -1 tell's GTK to unset the size request
        }
        this.node.setSizeRequest(width, height);
    }
}
GtkComponent.defaultProps = {
    style: {},
};
GtkComponent.defaultStyle = {};
exports.default = GtkComponent;
